@@ -1,4 +1,7 @@
-#' Create named list, possibly initialized with a certain element.
+#' @title Create named list, possibly initialized with a certain element
+#'
+#' @description
+#' Even an empty list will always be named.
 #'
 #' @param names [\code{character}]\cr
 #'   Names of elements.
@@ -9,14 +12,14 @@
 #' @export
 #' @examples
 #' namedList(c("a", "b"))
-#' namedList(c("a", "b"), init=1)
+#' namedList(c("a", "b"), init = 1)
 namedList = function(names, init) {
   if (missing(names))
-    return(list())
+    return(setNames(list(), character(0L)))
   n = length(names)
   if (missing(init))
     xs = vector("list", n)
   else
-    xs = replicate(n, init, simplify=FALSE)
+    xs = replicate(n, init, simplify = FALSE)
   setNames(xs, names)
 }
